==> haskell-zlib-0.7.0.0-66.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zlib
version:                0.7.0.0
visibility:             public
id:                     zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5
key:                    zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5
license:                BSD-3-Clause
copyright:              (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:                 Duncan Coutts <duncan@community.haskell.org>
synopsis:               Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:               Codec
abi:                    2ad690dc0cd89da85226e7136392dda4
exposed:                True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:            /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0
library-dirs:           /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-zlib
hs-libraries:           HSzlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5
extra-libraries:        z
extra-libraries-static: z
include-dirs:           /usr/include
includes:               zlib.h hs-zlib.h
depends:                base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:           /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.7.0.0-67-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zlib
version:                0.7.0.0
visibility:             public
id:                     zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw
key:                    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw
license:                BSD-3-Clause
copyright:              (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:                 Duncan Coutts <duncan@community.haskell.org>
synopsis:               Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:               Codec
abi:                    088c9810a9c86e9b253007da8c750d32
exposed:                True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:            /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0
library-dirs:           /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/zlib-0.7.0.0 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-zlib
hs-libraries:           HSzlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw
extra-libraries:        z
extra-libraries-static: z
include-dirs:           /usr/include
includes:               zlib.h hs-zlib.h
depends:                base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:           /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
